@@ -78,34 +78,56 @@ REPLACE_SYMS = {
     'Multi_key':    KeyRepl(False, True,  True,  _('Compose')),
 
     # Multimedia keys
-    'XF86AudioMute':         KeyRepl(True, True, True, [ReplData(_('\uf026'),  'FontAwesome', None),
-                                                        ReplData(_('Mute'),    None,          None)]),
-    'XF86AudioMicMute':      KeyRepl(True, True, True, [ReplData(_('\uf131'),  'FontAwesome', None),
-                                                        ReplData(_('Rec'),     None,          None)]),
-    'XF86AudioRaiseVolume':  KeyRepl(True, True, True, [ReplData(_('\uf028'),  'FontAwesome', None),
-                                                        ReplData(_('Vol'),     None,          '+')]),
-    'XF86AudioLowerVolume':  KeyRepl(True, True, True, [ReplData(_('\uf027'),  'FontAwesome', None),
-                                                        ReplData(_('Vol'),     None,          '-')]),
-    'XF86AudioPrev':         KeyRepl(True, True, True, [ReplData(_('\uf048'),  'FontAwesome', None),
-                                                        ReplData(_('Prev'),    None,          None)]),
-    'XF86AudioNext':         KeyRepl(True, True, True, [ReplData(_('\uf051'),  'FontAwesome', None),
-                                                        ReplData(_('Next'),    None,          None)]),
-    'XF86AudioPlay':         KeyRepl(True, True, True, [ReplData(_('\uf04b'),  'FontAwesome', None),
-                                                        ReplData(_('▶'),       None,          None)]),
-    'XF86AudioStop':         KeyRepl(True, True, True, [ReplData(_('\uf04d'),  'FontAwesome', None),
-                                                        ReplData(_('⬛'),       None,          None)]),
-    'XF86Eject':             KeyRepl(True, True, True, [ReplData(_('\uf052'),  'FontAwesome', None),
-                                                        ReplData(_('Eject'),   None,          None)]),
-    'XF86MonBrightnessDown': KeyRepl(True, True, True, [ReplData(_('\uf185'),  'FontAwesome', '-'),
-                                                        ReplData(_('Bright'),  None,          '-')]),
-    'XF86MonBrightnessUp':   KeyRepl(True, True, True, [ReplData(_('\uf185'),  'FontAwesome', '+'),
-                                                        ReplData(_('Bright'),  None,          '+')]),
-    'XF86Display':           KeyRepl(True, True, True, [ReplData(_('\uf108'),  'FontAwesome', None),
-                                                        ReplData(_('Display'), None,          None)]),
-    'XF86WLAN':              KeyRepl(True, True, True, [ReplData(_('\uf1eb'),  'FontAwesome', None),
-                                                        ReplData(_('WLAN'),    None,          None)]),
-    'XF86Search':            KeyRepl(True, True, True, [ReplData(_('\uf002'),  'FontAwesome', None),
-                                                        ReplData(_('Search'),  None,          None)]),
+    'XF86AudioMute':         KeyRepl(True, True, True, [ReplData(_('\uf026'),    'Font Awesome 5 Free', None),
+                                                        ReplData(_('\uf026'),    'FontAwesome',         None),
+                                                        ReplData(_('Mute'),      None,                  None)]),
+    'XF86AudioMicMute':      KeyRepl(True, True, True, [ReplData(_('\uf131'),    'Font Awesome 5 Free', None),
+                                                        ReplData(_('\uf131'),    'FontAwesome',         None),
+                                                        ReplData(_('Rec'),       None,                  None)]),
+    'XF86AudioRaiseVolume':  KeyRepl(True, True, True, [ReplData(_('\uf028'),    'Font Awesome 5 Free', None),
+                                                        ReplData(_('\uf028'),    'FontAwesome',         None),
+                                                        ReplData(_('Vol'),       None,                  '+')]),
+    'XF86AudioLowerVolume':  KeyRepl(True, True, True, [ReplData(_('\uf027'),    'Font Awesome 5 Free', None),
+                                                        ReplData(_('\uf027'),    'FontAwesome',         None),
+                                                        ReplData(_('Vol'),       None,                  '-')]),
+    'XF86AudioPrev':         KeyRepl(True, True, True, [ReplData(_('\uf048'),    'Font Awesome 5 Free', None),
+                                                        ReplData(_('\uf048'),    'FontAwesome',         None),
+                                                        ReplData(_('Prev'),      None,                  None)]),
+    'XF86AudioNext':         KeyRepl(True, True, True, [ReplData(_('\uf051'),    'Font Awesome 5 Free', None),
+                                                        ReplData(_('\uf051'),    'FontAwesome',         None),
+                                                        ReplData(_('Next'),      None,                  None)]),
+    'XF86AudioPlay':         KeyRepl(True, True, True, [ReplData(_('\uf04b'),    'Font Awesome 5 Free', None),
+                                                        ReplData(_('\uf04b'),    'FontAwesome',         None),
+                                                        ReplData(_('▶'),         None,                  None)]),
+    'XF86AudioStop':         KeyRepl(True, True, True, [ReplData(_('\uf04d'),    'Font Awesome 5 Free', None),
+                                                        ReplData(_('\uf04d'),    'FontAwesome',         None),
+                                                        ReplData(_('⬛'),         None,                  None)]),
+    'XF86Eject':             KeyRepl(True, True, True, [ReplData(_('\uf052'),    'Font Awesome 5 Free', None),
+                                                        ReplData(_('\uf052'),    'FontAwesome',         None),
+                                                        ReplData(_('Eject'),     None,                  None)]),
+    'XF86MonBrightnessDown': KeyRepl(True, True, True, [ReplData(_('\uf185'),    'Font Awesome 5 Free', '-'),
+                                                        ReplData(_('\uf185'),    'FontAwesome',         '-'),
+                                                        ReplData(_('Bright'),    None,                  '-')]),
+    'XF86MonBrightnessUp':   KeyRepl(True, True, True, [ReplData(_('\uf185'),    'Font Awesome 5 Free', '+'),
+                                                        ReplData(_('\uf185'),    'FontAwesome',         '+'),
+                                                        ReplData(_('Bright'),    None,                  '+')]),
+    'XF86Display':           KeyRepl(True, True, True, [ReplData(_('\uf108'),    'Font Awesome 5 Free', None),
+                                                        ReplData(_('\uf108'),    'FontAwesome',         None),
+                                                        ReplData(_('Display'),   None,                  None)]),
+    'XF86WLAN':              KeyRepl(True, True, True, [ReplData(_('\uf1eb'),    'Font Awesome 5 Free', None),
+                                                        ReplData(_('\uf1eb'),    'FontAwesome',         None),
+                                                        ReplData(_('WLAN'),      None,                  None)]),
+    'XF86Search':            KeyRepl(True, True, True, [ReplData(_('\uf002'),    'Font Awesome 5 Free', None),
+                                                        ReplData(_('\uf002'),    'FontAwesome',         None),
+                                                        ReplData(_('Search'),    None,                  None)]),
+    'XF86Bluetooth':         KeyRepl(True, True, True, [ReplData(_('\uf294'),    'Font Awesome 5 Free', None),
+                                                        ReplData(_('\uf294'),    'FontAwesome',         None),
+                                                        ReplData(_('Bluetooth'), None,                  None)]),
+    'XF86Tools':             KeyRepl(True, True, True, [ReplData(_('\uf7d9'),    'Font Awesome 5 Free', None),
+                                                        ReplData(_('🛠'),        None,                  None)]),
+    'XF86Favorites':         KeyRepl(True, True, True, [ReplData(_('\uf005'),    'Font Awesome 5 Free', None),
+                                                        ReplData(_('\uf005'),    'FontAwesome',         None),
+                                                        ReplData(_('🟊'),        None,                  None)]),
 }
 
 WHITESPACE_SYMS = {'Tab', 'ISO_Left_Tab', 'Return', 'space', 'KP_Enter'}
@@ -124,10 +146,12 @@ REPLACE_MODS = {
     'ctrl':   {'normal': _('Ctrl+'),  'emacs': 'C-', 'mac': _('⌘+')},
     'alt':    {'normal': _('Alt+'),   'emacs': 'M-', 'mac': _('⌥+')},
     'super':  {'normal': _('Super+'), 'emacs': 's-',
-               'win': [ReplData(_('\uf17a'), 'FontAwesome', '+'),
-                       ReplData(_('Win'),    None,          '+')],
-               'tux': [ReplData(_('\uf17c'), 'FontAwesome', '+'),
-                       ReplData(_('Super'),  None,          '+')]},
+               'win': [ReplData(_('\uf17a'), 'Font Awesome 5 Free', '+'),
+                       ReplData(_('\uf17a'), 'FontAwesome',         '+'),
+                       ReplData(_('Win'),    None,                  '+')],
+               'tux': [ReplData(_('\uf17c'), 'Font Awesome 5 Free', '+'),
+                       ReplData(_('\uf17c'), 'FontAwesome',         '+'),
+                       ReplData(_('Super'),  None,                  '+')]},
     'hyper':  {'normal': _('Hyper+'), 'emacs': 'H-'},
     'alt_gr': {'normal': _('AltGr+'), 'emacs': 'AltGr-'},
 }
@@ -142,14 +166,15 @@ def keysym_to_mod(keysym):
 
 class LabelManager(object):
     def __init__(self, listener, logger, key_mode, bak_mode, mods_mode, mods_only,
-                 multiline, vis_shift, vis_space, recent_thr, compr_cnt, ignore, pango_ctx):
+                 multiline, vis_shift, vis_space, recent_thr, compr_cnt, ignore,
+                 pango_ctx, enabled):
         self.key_mode = key_mode
         self.bak_mode = bak_mode
         self.mods_mode = mods_mode
         self.logger = logger
         self.listener = listener
         self.data = []
-        self.enabled = True
+        self.enabled = enabled
         self.mods_only = mods_only
         self.multiline = multiline
         self.vis_shift = vis_shift
